library(lubridate)
library(dplyr)
library(ISOweek)
#library(plyr)

library(ggplot2)
library(yaml)

library(RMySQL)


#Importamos los datos por ccaa para extrapolar al total de la población
setwd("~/MoMo/Modelos/Articulo/DATOS/Datos_articulo_mortalidad_2020")
# Functions
source("get_poblaciones.R")

# Configuration
config <- yaml.load_file("config.yaml")


config$db_connection <- openDbConnection(config)

query<-"select ine.ccaa_cod_ine, ine.provincia_cod_ine, num_defs_mju, num_defs_ine
from (
  select p.cod_ine provincia_cod_ine, max(c.cod_ine) ccaa_cod_ine, count(1) num_defs_ine
  from defuncion_historico dh
  join municipio m on dh.municipio_defuncion_id = m.id
  join provincia p on m.provincia_id = p.id
  join ccaa c on p.ccaa_id = c.id
  cross join fecha_defuncion_historico fdh
  where year(dh.fecha_defuncion) = year(fdh.max_fecha)
  group by 1
) ine
join (
  select p.cod_ine provincia_cod_ine, count(1) num_defs_mju
  from defuncion d
  join municipio m on d.municipio_id = m.id
  join provincia p on m.provincia_id = p.id
  cross join fecha_defuncion_historico fdh
  where year(d.fecha_defuncion) = year(fdh.max_fecha)
  group by 1
) mju on ine.provincia_cod_ine = mju.provincia_cod_ine"

correccion<- getQueryResult(config, query)
correccion$factor<-round(1/(correccion$num_defs_mju/correccion$num_defs_ine),4)


correccion_ccaa <- correccion %>%
  group_by(ccaa_cod_ine) %>%
  summarize(num_defs_mju=sum(num_defs_mju), num_defs_ine=sum(num_defs_ine))

correccion_ccaa$factor<-round(1/(correccion_ccaa$num_defs_mju/correccion_ccaa$num_defs_ine),4)

correccion$total<-1
correccion_nacional <- correccion %>%
  group_by(total) %>%
  summarize(num_defs_mju=sum(num_defs_mju), num_defs_ine=sum(num_defs_ine))

correccion_nacional$factor<-round(1/(correccion_nacional$num_defs_mju/correccion_nacional$num_defs_ine),4)


#Figure 1. Weekly excess all-cause mortality (number of deaths). MoMo, Spain, 2014-2021
#Descargo los datos de mortalidad MoMo semanales
defunciones_sem<-read.csv(file.path("C:/Users/ileon/Documents/MoMo/Modelos/Articulo/DATOS/Datos_articulo_mortalidad_2020/salidas_modelo/agregacion_semanal_nacional.csv"), sep = ",", header =TRUE, stringsAsFactors = FALSE)

#Restringo a las observacones totales
defunciones_sem<-defunciones_sem[defunciones_sem$group=="Total" & defunciones_sem$ano>=2014,]

defunciones_sem<-defunciones_sem[defunciones_sem$ano<=2020 | (defunciones_sem$ano==2021 & defunciones_sem$semana<=12),]

#Aplico la corrección 
defunciones_sem$esperado_m_c<-defunciones_sem$esperado_m*correccion_nacional$factor
defunciones_sem$observado_m_c<-defunciones_sem$observado_m*correccion_nacional$factor
defunciones_sem$q99_m_c<-defunciones_sem$q99_m*correccion_nacional$factor

#Calculo el exceso
defunciones_sem$exceso_c<-defunciones_sem$observado_m_c-defunciones_sem$esperado_m_c


#Genero el gráfico
jpeg("Y:/COVID-19/Artículo2_MoMo_Covid19 deaths/Manuscrito/Figuras_tablas/Figure1.jpeg",units="in", width=20, height=15, res=300)

par(mar=c(10,5,4,2))
plot.ts(defunciones_sem$esperado_m_c, axes=F, ylab="",xlab="",cex.sub=3,cex=3,cex.lab=3,col="chartreuse4",lwd=3,ylim=c(5000, 21000) )
mtext("Year", side=1, line=3, cex=1.5)
mtext("Deaths number", side=2, line=3, cex=1.5)
lines(defunciones_sem$observado_m_c, col="blue")
#lines(defunciones_sem$q99_m_c, col=1, lty=2)

legend("bottom", horiz=TRUE, inset=c(0,-0.22),legend=c("observed deaths","expected deaths"), col=c("blue","chartreuse4"), lwd = c(1,3),text.fon=1,cex=1.5,adj=0,xpd = TRUE)

anos<-c( "2014", "2015","2016", "2017", "2018", "2019", "2020", "2021","")

axis(1,at=cumsum(c(0, 52, 53, 52, 52, 52, 53, 52,52)), labels=anos, cex.axis=1.5,cex.lab=1.5)
axis(2,cex.axis=1.5,cex.lab=1.5)

#tiff('Y:/COVID-19/articulo_MoMo_COVID19/Resultados/Graficos/fig1.tiff', units="in", width=50, height=40, res=300, compression = 'lzw')
dev.off()

jpeg("Y:/COVID-19/Artículo2_MoMo_Covid19 deaths/Manuscrito/Figuras_tablas/Figure1_BN.jpeg",units="in", width=15, height=10, res=300)

par(mar=c(10,5,4,2))
plot.ts(defunciones_sem$esperado_m_c, axes=F, ylab="",xlab="",cex.sub=3,cex=3,cex.lab=3,col="grey0",lwd=4,ylim=c(5000, 21000) )
mtext("Year", side=1, line=3, cex=1.5)
mtext("Deaths number", side=2, line=3, cex=1.5)
lines(defunciones_sem$observado_m_c, col="grey40")
#lines(defunciones_sem$q99_m_c, col=1, lty=2)

legend("bottom", horiz=TRUE, inset=c(0,-0.22),legend=c("observed deaths","expected deaths"), col=c("grey40","grey0"), lwd = c(1,4),text.fon=1,cex=1.5,adj=0,xpd = TRUE)

anos<-c( "2014", "2015","2016", "2017", "2018", "2019", "2020", "2021","")

axis(1,at=cumsum(c(0, 52, 53, 52, 52, 52, 53, 52,52)), labels=anos, cex.axis=1.5,cex.lab=1.5)
axis(2,cex.axis=1.5,cex.lab=1.5)

#tiff('Y:/COVID-19/articulo_MoMo_COVID19/Resultados/Graficos/fig1.tiff', units="in", width=50, height=40, res=300, compression = 'lzw')
dev.off()


#Figura3. Defunciones COVID-19 Y Excesos de defunciones MoMo
#Importamos las defunciones diarias: a fecha de ejecucion 11/05/2020
defunciones <- read.csv(file.path("C:/Users/ileon/Documents/MoMo/Modelos/Articulo/DATOS/Datos_articulo_mortalidad_2020/salidas_modelo/momo_nacional_edad.csv"), sep = ",", header =TRUE, stringsAsFactors = FALSE)


#Convertimos a fecha la fecha de defunciones y calculamos el mes
defunciones$fechadef = as.Date(defunciones$fecha_defuncion)
defunciones$mesdefn <- month(defunciones$fechadef)
defunciones$anodefn <- year(defunciones$fechadef)
defunciones$isoweek_defuncion = isoweek(defunciones$fecha_defuncion)


#Calculamos el exceso y aplicamos corrección
defunciones$exceso<-round(defunciones$defunciones_observadas-defunciones$defunciones_esperadas)
defunciones$factor_correc<-correccion_nacional$factor

defunciones$defunciones_observadas_c<-defunciones$defunciones_observadas*correccion_nacional$factor
defunciones$defunciones_esperadas_c<-defunciones$defunciones_esperadas*correccion_nacional$factor
defunciones$defunciones_esperadas_q01_c<-defunciones$defunciones_esperadas_q01*correccion_nacional$factor
defunciones$defunciones_esperadas_q99_c<-defunciones$defunciones_esperadas_q99*correccion_nacional$factor

defunciones$exceso1<-defunciones$defunciones_observadas-defunciones$defunciones_esperadas

defunciones$exceso1_c<-defunciones$defunciones_observadas_c-defunciones$defunciones_esperadas_c

#Asignamos el periodo de ola
defunciones$periodo<-0
defunciones$periodo<-ifelse((defunciones$fechadef>="2020-03-01" & defunciones$fechadef<="2020-06-21"),1,defunciones$periodo)
defunciones$periodo<-ifelse((defunciones$fechadef>="2020-06-22" & defunciones$fechadef<="2020-12-06"),2,defunciones$periodo)
defunciones$periodo<-ifelse((defunciones$fechadef>="2020-12-07" & defunciones$fechadef<="2021-03-14"),3,defunciones$periodo)



#Calculamos tabla de exceso de defunciones entre marzo y mayo de 2020 para el nacional
defunciones2020<-defunciones[(defunciones$fechadef>="2020-03-01" & defunciones$fechadef<="2021-03-31"),]
defunciones2020_nacional<-defunciones2020[defunciones2020$ambito == "nacional",] 


grafico3<-defunciones2020_nacional %>%
  group_by(cod_gedad, fechadef)  %>%
  summarize(exceso= sum(exceso1_c))%>%
  mutate(defs_exceso_cum = cumsum(exceso)) %>%
  arrange(cod_gedad, fechadef)



#Figure 2. Daily cumulated excess all-cause mortality (number of deaths) by age group. MoMo, Spain, 2014-2021.
#plot.ts(grafico3[grafico3$cod_gedad=="all",]$defs_exceso_cum, axes=F, xlab="Months",ylab="Cumulated excess deaths", col="black")
jpeg("Y:/COVID-19/Artículo2_MoMo_Covid19 deaths/Manuscrito/Figuras_tablas/Figure2.jpeg", units="in", width=15, height=10, res=300)
#windows(width = 4.5, height = 4)

par(mar=c(13,5,1,2))
plot.ts(grafico3[grafico3$cod_gedad=="mas_85",]$defs_exceso_cum, lwd=4, axes=F, xlab="",ylab="", col="cornflowerblue")
mtext("Month/year", side=1, line=3, cex=1.5)
mtext("Cumulated excess deaths", side=2, line=3, cex=1.5)
lines(grafico3[grafico3$cod_gedad=="0_14",]$defs_exceso_cum, col="blue", lwd=4)
lines(grafico3[grafico3$cod_gedad=="15_44",]$defs_exceso_cum, col="darkgrey", lwd=4)
lines(grafico3[grafico3$cod_gedad=="45_64",]$defs_exceso_cum, col="darkgreen", lwd=4)
lines(grafico3[grafico3$cod_gedad=="65_74",]$defs_exceso_cum, col="darkorchid", lwd=4)
lines(grafico3[grafico3$cod_gedad=="75_84",]$defs_exceso_cum, col="brown2", lwd=4)
legend("bottom", horiz=TRUE, inset=c(0,-0.2),legend=c("0 - 14 years","15 - 44 years","45 - 64 years","65 -74 years","75 -84 years","More 85 year"), lwd=c(2,2,2,2,2,2), col=c("blue","darkgrey","darkgreen","darkorchid","brown2","cornflowerblue"),cex=1.25,xpd = TRUE)

meses<-c( "Mar/2020", "Apr/2020","May/2020", "Jun/2020", "Jul/2020", "Ago/2020", "Sep/2020", "Oct/2020", "Nov/2020", "Dec/2020", "Jan/2021", "Feb/2021", "Mar/2021", "Apr/2021")

axis(1,at=cumsum(c(0, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31, 31, 28, 31)), labels=meses,cex.axis=1.5)
axis(2,cex.axis=1.5)

dev.off()


jpeg("Y:/COVID-19/Artículo2_MoMo_Covid19 deaths/Manuscrito/Figuras_tablas/Figure2_BN.jpeg", units="in", width=15, height=10, res=300)
#windows(width = 4.5, height = 4)

par(mar=c(13,5,1,2))
plot.ts(grafico3[grafico3$cod_gedad=="mas_85",]$defs_exceso_cum, lwd=4, lty=1, axes=F, xlab="",ylab="", col="grey0")
mtext("Month/year", side=1, line=3, cex=1.5)
mtext("Cumulated excess deaths", side=2, line=3, cex=1.5)
lines(grafico3[grafico3$cod_gedad=="0_14",]$defs_exceso_cum, col="grey50", lwd=2, lty = 2)
lines(grafico3[grafico3$cod_gedad=="15_44",]$defs_exceso_cum, col="grey0", lwd=4, lty = 4)
lines(grafico3[grafico3$cod_gedad=="45_64",]$defs_exceso_cum, col="grey50", lwd=4, lty = 3)
lines(grafico3[grafico3$cod_gedad=="65_74",]$defs_exceso_cum, col="grey0", lwd=4, lty = 3)
lines(grafico3[grafico3$cod_gedad=="75_84",]$defs_exceso_cum, col="grey50", lwd=4, lty = 1)

legend("bottom", horiz=TRUE, inset=c(0,-0.2),legend=c("0 - 14 years","15 - 44 years","45 - 64 years","65 -74 years","75 -84 years","More 85 year"), lwd=c(4,4,4,4,4,4), lty=c(2,4,3,3,1,1), col=c("grey50","grey0","grey50","grey0","grey50","grey0"),cex=1.25,xpd = TRUE)

meses<-c( "Mar/2020", "Apr/2020","May/2020", "Jun/2020", "Jul/2020", "Ago/2020", "Sep/2020", "Oct/2020", "Nov/2020", "Dec/2020", "Jan/2021", "Feb/2021", "Mar/2021", "Apr/2021")

axis(1,at=cumsum(c(0, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31, 31, 28, 31)), labels=meses,cex.axis=1.5)
axis(2,cex.axis=1.5)

dev.off()



#Importamos los datos de covid
options(encoding = "UTF-8")
covid<-read.csv(file.path("C:/Users/ileon/Documents/MoMo/Modelos/Articulo/DATOS/Datos_articulo_mortalidad_2020/salidas_modelo/20210510_defuncionesSivies.csv"), sep = ",", header =TRUE, stringsAsFactors = FALSE)

#Creamos variables de fecha
covid$ano<-substr(covid$fecha, start = 7, stop = 10)
covid$mes<-substr(covid$fecha, start = 4, stop = 5)
covid$dia<-substr(covid$fecha, start = 1, stop = 2)
covid$ano<-ifelse(covid$ano==2121,2021,covid$ano)
covid$date2<-paste(covid$ano, covid$mes, covid$dia, sep = "-")

covid$date = as.Date(covid$date2)

covid$mesdefn <- month(covid$date)
covid$anodefn <- year(covid$date)
covid$isoweek_defuncion = isoweek(covid$date)

#Genero la variable defuncion
covid$def<-1


#Figura 3. Daily excess all-cause estimated number of deaths by MoMo and COVID-19 deaths reported to RENAVE. Spain. March 2020 - March 2021

MOMOAcumulados14_PROV<-readRDS(file="C:/Users/ileon/Documents/MoMo/Modelos/Articulo/DATOS/Datos_articulo_mortalidad_2020/salidas_modelo/results/MOMOAcumulados14_PROV.rds")

COVIDAcumulados14_PROV<-readRDS(file="C:/Users/ileon/Documents/MoMo/Modelos/Articulo/DATOS/Datos_articulo_mortalidad_2020/salidas_modelo/results/COVIDAcumulados14_PROV.rds")

acumulados14_Prov<-merge(MOMOAcumulados14_PROV, COVIDAcumulados14_PROV, by = c("finRango","PROV"), all = TRUE)


jpeg("Y:/COVID-19/Artículo2_MoMo_Covid19 deaths/Manuscrito/Figuras_tablas/Figure3_BN.jpeg", units="in", width=15, height=10, res=300)

par(mar=c(13,5,1,5))
plot.ts(acumulados14_Prov[MOMOAcumulados14_PROV$PROV==0,]$valor.x, axes=F,xlab="",ylab="", ylim=c(-150,24000))
mtext("Month/year", side=1, line=3, cex=1.5)
mtext("Number of excess deaths", side=2, line=3, cex=1.5)
par(new=TRUE)
plot.ts(acumulados14_Prov[acumulados14_Prov$PROV==0,]$valor.y, col=1,lwd=3, axes=F,xlab="",ylab="", ylim=c(-150,24000))
mtext(" Number of COVID-19 deaths", side=4, line=3, cex=1.5)

meses<-c( "Mar/2020", "Apr/2020","May/2020", "Jun/2020", "Jul/2020", "Ago/2020", "Sep/2020", "Oct/2020", "Nov/2020", "Dec/2020", "Jan/2021", "Feb/2021", "Mar/2021", "Apr/2021")

axis(1,at=cumsum(c(0, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31, 31, 28, 31)), labels=meses,cex.axis=1.5)
axis(2,cex.axis=1.5)
axis(4,cex.axis=1.5)

legend("bottom", inset=c(0,-0.2), horiz=TRUE,cex=1.5,xpd = TRUE,legend=c("14 days cumulated excess deaths","14 days cumulated COVID-19 deaths"), col=c("1","1"),lwd=c(1,3),text.fon=1)


dev.off()

plot.ts(acumulados14_Prov[acumulados14_Prov$PROV==4,]$valor.x, axes=F,xlab="week",ylab="Excess deaths/ Covid deaths")

lines(acumulados14_Prov[acumulados14_Prov$PROV==4,]$valor.y, col=1,lwd=3)


meses<-c( "March", "April","May", "Jun", "Jul", "Ago", "Sep", "Oct", "Nov", "Dec", "Jan", "Feb", "March", "")

axis(1,at=cumsum(c(0, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31, 31, 28, 31)), labels=meses)
axis(2)


#	Table 1. Excess all-cause mortality estimates by MoMo and COVID-19 deaths reported to RENAVE by wave, Spain. March 2020 - March 2021.
#Recodifico los grupos de edad
defunciones2020_nacional$gedad<-0
defunciones2020_nacional$gedad<-ifelse((defunciones2020_nacional$cod_gedad=="0_14"),1,defunciones2020_nacional$gedad)
defunciones2020_nacional$gedad<-ifelse((defunciones2020_nacional$cod_gedad=="15_44"),2,defunciones2020_nacional$gedad)
defunciones2020_nacional$gedad<-ifelse((defunciones2020_nacional$cod_gedad=="45_64"),3,defunciones2020_nacional$gedad)
defunciones2020_nacional$gedad<-ifelse((defunciones2020_nacional$cod_gedad=="65_74"),4,defunciones2020_nacional$gedad)
defunciones2020_nacional$gedad<-ifelse((defunciones2020_nacional$cod_gedad=="75_84" ),5,defunciones2020_nacional$gedad)
defunciones2020_nacional$gedad<-ifelse((defunciones2020_nacional$cod_gedad=="mas_85" ),6,defunciones2020_nacional$gedad)
defunciones2020_nacional$gedad<-ifelse((defunciones2020_nacional$cod_gedad=="all" ),99,defunciones2020_nacional$gedad)



Tabla1<-defunciones2020_nacional[defunciones2020_nacional$cod_sexo=="all",] %>%
  group_by(periodo, gedad)  %>%
  summarize(Exceso= sum(exceso1_c), def_esp=sum(defunciones_esperadas_c), def_obs= sum(defunciones_observadas_c), Porcen=round(((def_obs-def_esp)/def_esp)*100))%>%
  select(periodo, gedad, Exceso, Porcen)%>%
  arrange(periodo, gedad)



#Marco las diferentes en los datos de defunciones covid
covid$periodo<-0
covid$periodo<-ifelse((covid$date>="2020-03-10" & covid$date<="2020-06-21"),1,covid$periodo)
covid$periodo<-ifelse((covid$date>="2020-06-22" & covid$date<="2020-12-06"),2,covid$periodo)
covid$periodo<-ifelse((covid$date>="2020-12-07" & covid$date<="2021-03-14"),3,covid$periodo)



#Recodifico la variable edad
covid$gedad<-0
covid$gedad<-ifelse((covid$edad>=0 & covid$edad<=14),1,covid$gedad)
covid$gedad<-ifelse((covid$edad>=15 & covid$edad<=44),2,covid$gedad)
covid$gedad<-ifelse((covid$edad>=45 & covid$edad<=64),3,covid$gedad)
covid$gedad<-ifelse((covid$edad>=65 & covid$edad<=74),4,covid$gedad)
covid$gedad<-ifelse((covid$edad>=75 & covid$edad<=84),5,covid$gedad)
covid$gedad<-ifelse((covid$edad>=85 ),6,covid$gedad)


#Calculo las defunciones por ola y grupo de edad
Tabla1b<-covid %>%
  group_by(periodo, gedad)  %>%
  summarize(def_covid= sum(def))%>%
  select(periodo, gedad, def_covid)%>%
  arrange(periodo, gedad)





Tabla1_mostrar<-merge(Tabla1, Tabla1b, by = c("periodo", "gedad"), all = TRUE)

Tabla1_mostrar$gedadc<-"0"
Tabla1_mostrar$gedadc<-ifelse((Tabla1_mostrar$gedad==1),"0_14",Tabla1_mostrar$gedadc)
Tabla1_mostrar$gedadc<-ifelse((Tabla1_mostrar$gedad==2),"15_44",Tabla1_mostrar$gedadc)
Tabla1_mostrar$gedadc<-ifelse((Tabla1_mostrar$gedad==3),"45_64",Tabla1_mostrar$gedadc)
Tabla1_mostrar$gedadc<-ifelse((Tabla1_mostrar$gedad==4),"65_74",Tabla1_mostrar$gedadc)
Tabla1_mostrar$gedadc<-ifelse((Tabla1_mostrar$gedad==5),"75_84",Tabla1_mostrar$gedadc)
Tabla1_mostrar$gedadc<-ifelse((Tabla1_mostrar$gedad==6),"mas_85",Tabla1_mostrar$gedadc)
Tabla1_mostrar$gedadc<-ifelse((Tabla1_mostrar$gedad==99),"all",Tabla1_mostrar$gedadc)


Tabla1_mostrar$periodoc<-"0"
Tabla1_mostrar$periodoc<-ifelse((Tabla1_mostrar$periodo==1),"2020-03-10 - 2020-06-21",Tabla1_mostrar$periodoc)
Tabla1_mostrar$periodoc<-ifelse((Tabla1_mostrar$periodo==2),"2020-06-22 - 2020-12-06",Tabla1_mostrar$periodoc)
Tabla1_mostrar$periodoc<-ifelse((Tabla1_mostrar$periodo==3),"2020-12-07- 2021-03-14",Tabla1_mostrar$periodoc)


Tabla1_mostrar<-Tabla1_mostrar[Tabla1_mostrar!=0,] %>%
  group_by(periodoc, gedadc)  %>%
  summarize(Exceso= sum(Exceso), Porcen=sum(Porcen), Def_covid=sum(def_covid))%>%
  select(periodoc, gedadc, Exceso, Def_covid, Porcen)

#Tabla 2. Defunciones y excesos por ola epidémica y grupo de edad por CCAA (totales en cada grupo)
#Importo las defunciones por comunidad auntónoma
defunciones_prov <- read.csv(file.path("C:/Users/ileon/Documents/MoMo/Modelos/Articulo/DATOS/Datos_articulo_mortalidad_2020/salidas_modelo/momo_nacional.csv"), sep = ",", header =TRUE, stringsAsFactors = FALSE)

#Filtro las defunciones por Comunidad Autónoma
defunciones2020_ccaa<-defunciones_prov[defunciones_prov$ambito == "cod_ccaa",] 

#Hago calculos de fechas
defunciones2020_ccaa$fechadef = as.Date(defunciones2020_ccaa$fecha_defuncion)
defunciones2020_ccaa$mesdefn <- month(defunciones2020_ccaa$fechadef)
defunciones2020_ccaa$anodefn <- year(defunciones2020_ccaa$fechadef)
defunciones2020_ccaa$exceso<-round(defunciones2020_ccaa$defunciones_observadas-defunciones2020_ccaa$defunciones_esperadas)
defunciones2020_ccaa$isoweek_defuncion = isoweek(defunciones2020_ccaa$fecha_defuncion)

#Restringo por periodo de interés
defunciones2020_ccaa<-defunciones2020_ccaa[(defunciones2020_ccaa$fechadef>="2020-03-01" & defunciones2020_ccaa$fechadef<="2021-03-31"),] 

#Asigno la corrección en las defunciones
defunciones2020_ccaa<-merge(defunciones2020_ccaa,correccion_ccaa,by.x ="cod_ine_ambito",by.y="ccaa_cod_ine", all = TRUE)
                                  
defunciones2020_ccaa$defunciones_observadas_c<-defunciones2020_ccaa$defunciones_observadas*defunciones2020_ccaa$factor
defunciones2020_ccaa$defunciones_esperadas_c<-defunciones2020_ccaa$defunciones_esperadas*defunciones2020_ccaa$factor
defunciones2020_ccaa$defunciones_esperadas_q01_c<-defunciones2020_ccaa$defunciones_esperadas_q01*defunciones2020_ccaa$factor
defunciones2020_ccaa$defunciones_esperadas_q99_c<-defunciones2020_ccaa$defunciones_esperadas_q99*defunciones2020_ccaa$factor

#Calculo excesos
defunciones2020_ccaa$exceso1<-defunciones2020_ccaa$defunciones_observadas-defunciones2020_ccaa$defunciones_esperadas

defunciones2020_ccaa$exceso1_c<-defunciones2020_ccaa$defunciones_observadas_c-defunciones2020_ccaa$defunciones_esperadas_c                                          

#Asigno periodos de olas
defunciones2020_ccaa$periodo<-0
defunciones2020_ccaa$periodo<-ifelse((defunciones2020_ccaa$fechadef>="2020-03-01" & defunciones2020_ccaa$fechadef<="2020-06-21"),1,defunciones2020_ccaa$periodo)
defunciones2020_ccaa$periodo<-ifelse((defunciones2020_ccaa$fechadef>="2020-06-22" & defunciones2020_ccaa$fechadef<="2020-12-06"),2,defunciones2020_ccaa$periodo)
defunciones2020_ccaa$periodo<-ifelse((defunciones2020_ccaa$fechadef>="2020-12-07" & defunciones2020_ccaa$fechadef<="2021-03-14"),3,defunciones2020_ccaa$periodo)


defunciones2020_ccaa$gedad<-0
defunciones2020_ccaa$gedad<-ifelse((defunciones2020_ccaa$cod_gedad=="0_14"),1,defunciones2020_ccaa$gedad)
defunciones2020_ccaa$gedad<-ifelse((defunciones2020_ccaa$cod_gedad=="15_44"),2,defunciones2020_ccaa$gedad)
defunciones2020_ccaa$gedad<-ifelse((defunciones2020_ccaa$cod_gedad=="45_64"),3,defunciones2020_ccaa$gedad)
defunciones2020_ccaa$gedad<-ifelse((defunciones2020_ccaa$cod_gedad=="65_74"),4,defunciones2020_ccaa$gedad)
defunciones2020_ccaa$gedad<-ifelse((defunciones2020_ccaa$cod_gedad=="75_84" ),5,defunciones2020_ccaa$gedad)
defunciones2020_ccaa$gedad<-ifelse((defunciones2020_ccaa$cod_gedad=="mas_85" ),6,defunciones2020_ccaa$gedad)
defunciones2020_ccaa$gedad<-ifelse((defunciones2020_ccaa$cod_gedad=="all" ),99,defunciones2020_ccaa$gedad)



tabla_momo_ccaa<-defunciones2020_ccaa[defunciones2020_ccaa$cod_sexo=="all",] %>%
  group_by(periodo, cod_ine_ambito, cod_ambito)  %>%
  summarize(Exceso= sum(exceso1_c), def_esp=sum(defunciones_esperadas_c), def_obs= sum(defunciones_observadas_c), Porcen=round(((def_obs-def_esp)/def_esp)*100))%>%
  select(periodo, cod_ine_ambito, cod_ambito, Exceso, Porcen)%>%
  arrange(periodo, cod_ine_ambito, cod_ambito)





covid$cod_iso_ccaa<-"99"
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Almería",1,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Cádiz",1,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Córdoba",1,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Granada",1,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Huelva",1,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Jaén",1,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Málaga",1,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Sevilla",1,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Huesca",2,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Teruel",2,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Zaragoza",2,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Asturias",3,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Baleares",4,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Las Palmas",5,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Santa Cruz",5,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Cantabria",6,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Ávila",7,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Burgos",7,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="León",7,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Palencia",7,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Salamanca",7,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Segovia",7,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Soria",7,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Valladolid",7,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Zamora",7,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Albacete",8,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Ciudad Real",8,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Cuenca",8,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Guadalajara",8,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Toledo",8,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Barcelona",9,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Girona",9,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Lleida",9,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Tarragona",9,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Alicante",10,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Castellón",10,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Valencia",10,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Badajoz",11,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Cáceres",11,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="A Coruña",12,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Lugo",12,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Ourense",12,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Pontevedra",12,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Madrid",13,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Murcia",14,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Navarra",15,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Álava",16,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Vizcaya",16,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Gipuzkoa",16,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="La Rioja",17,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Ceuta",18,covid$cod_iso_ccaa)
covid$cod_iso_ccaa<-ifelse(covid$provincia2=="Melilla",19,covid$cod_iso_ccaa)





tabla_covid_ccaa<-covid %>%
  group_by(periodo, cod_iso_ccaa)  %>%
  summarize(def_covid= sum(def))%>%
  select(periodo, cod_iso_ccaa,  def_covid)

Tabla_ccaa<-merge(tabla_momo_ccaa, tabla_covid_ccaa, by.x=c("periodo","cod_ine_ambito"), by.y=c("periodo","cod_iso_ccaa"),  all = TRUE)

#Table 2. Excess all-cause mortality estimates by MoMo and COVID-19 deaths reported to RENAVE by autonomous com-munities, Spain. March 2020 - March 2021.
Tabla_ccaa_resumen<-Tabla_ccaa%>%
  group_by(cod_ine_ambito)  %>%
  summarize(Exceso=sum(Exceso), def_covid= sum(def_covid))



#Table 3.
tabla_por_anos<-defunciones_sem%>%
  group_by(ano)%>%
  summarize(exceso_MoMo= sum(exceso_c))

#Importamos los resultados de EuroMoMo: a fecha de ejecucion 11/05/2020
EuroMoMo <- read.table("M:/sistemas_momo/modelos_mortalidad/euromomo/MOMOv4-3-Spain-2021-18/EUROMOMO-COMPLETE-Spain-2021-18/EUROMOMOv4-3-COMPLETE-Spain-2021-18.txt", sep=",", dec=".", header=T)
Euromomo_T<-EuroMoMo[EuroMoMo$group=="Total",]
Euromomo_T$excess_c<-Euromomo_T$excess*correccion_nacional$factor


tabla_EuroMoMo_anos<-Euromomo_T%>%
  group_by(YoDi)%>%
  summarize(excess_EuroMoMo= sum(excess_c))


Tabla_resumen_MoMo_EuroMoMo<-merge(tabla_por_anos, tabla_EuroMoMo_anos, by.x="ano", by.y="YoDi" )



