library(yaml)
library(nlme)
library(RMySQL)
library(lubridate)
library(dplyr)
library(readstata13)


require(foreign)
require(raster)
require(reshape2)
require(RColorBrewer)
require(maptools)
require(sp)
require(rgeos)
require(rgdal)
require(sf)
require(data.table)

######## MAPA provinciales de España de excesos de mortalidad
setwd("C:/Users/ileon/Documents/MoMo/Modelos/Articulo/DATOS/Datos_articulo_mortalidad_2020/salidas_modelo")



mapa = readOGR("provincia.shp")


row.names(mapa@data)<-c(1:dim(mapa)[1])
#Municipios=mapa$municipios<-sub(" ","0",format(mapa$CODMUNI_NE,justify="right"))
Provincias=mapa$PROV
#Peninsula=subset(mapa,!CODPROV %in% c(35,38))
temp<-unionSpatialPolygons(mapa,mapa$PROV) 
DF=data.frame(provincias=names(temp),row.names=names(temp))
mapa.P=SpatialPolygonsDataFrame(temp, DF, match.ID = TRUE)

Peninsula=subset(mapa.P,!provincias %in% c(35,38))
Canarias=subset(mapa.P,provincias %in% c(35,38))

#dy <- bbox(Peninsula)[2,1] - bbox(Canarias)[2,1]
#dx <- bbox(Peninsula)[1,2] + bbox(Canarias)[1,2]
#Canarias.move <- elide(Canarias, shift=c(dx, dy))
mapa.P=rbind(Peninsula,Canarias)



setwd("C:/Users/ileon/Documents/MoMo/Modelos/Articulo/DATOS/Datos_articulo_mortalidad_2020")

#Obtengo la poblacion

config <- modifyList(
  #yaml.load_file("config/config.yaml"),
  yaml.load_file("config1/config.yaml")
)

for (fichero in dir("funciones", pattern = "*.R", full.names = T))
  source(fichero)

# rango de fechas que se muestra en los gráficos (14 meses)



config$db_connection <- openDbConnection()

ejecuta(poblacion_prov    <- obtenerPoblacion(),    "Obteniendo datos de población por provincias")


# Limpieza del proceso: cierre de conexión a BD
closeDbConnection()

#Importo los datos de defunciones

defunciones_tasasB<-read.csv(file.path("C:/Users/ileon/Documents/MoMo/Modelos/Articulo/DATOS/Datos_articulo_mortalidad_2020/salidas_modelo/momo_nacional_prov_edad.csv"), sep = ",", header =TRUE, stringsAsFactors = FALSE)

#Creo variables de fecha
defunciones_tasasB$fdef = as.Date(defunciones_tasasB$fecha_defuncion)
defunciones_tasasB$mesdefn <- month(defunciones_tasasB$fdef)
defunciones_tasasB$anodefn <- year(defunciones_tasasB$fdef)

#Recodifico los grupos de edad
defunciones_tasasB$gredad <- 9
defunciones_tasasB$gredad[defunciones_tasasB$cod_gedad == "0_14"] <- 1
defunciones_tasasB$gredad[defunciones_tasasB$cod_gedad == "15_44"] <- 2
defunciones_tasasB$gredad[defunciones_tasasB$cod_gedad == "45_64"] <- 3
defunciones_tasasB$gredad[defunciones_tasasB$cod_gedad == "65_74"] <- 4
defunciones_tasasB$gredad[defunciones_tasasB$cod_gedad == "75_84"] <- 5
defunciones_tasasB$gredad[defunciones_tasasB$cod_gedad == "mas_85"] <- 6
defunciones_tasasB$def<-1

#Aplicamos factor de correccion
defunciones_tasasB<-merge(defunciones_tasasB,correccion,by.x ="cod_ine_ambito",by.y="provincia_cod_ine", all = TRUE)


#Filtro por datos nacionales
defunciones_tasasB[defunciones_tasasB$ambito=="nacional",]$defunciones_observadas_c<-defunciones_tasasB[defunciones_tasasB$ambito=="nacional",]$defunciones_observadas*correccion_nacional$factor
defunciones_tasasB[defunciones_tasasB$ambito=="nacional",]$defunciones_esperadas_c<-defunciones_tasasB[defunciones_tasasB$ambito=="nacional",]$defunciones_esperadas*correccion_nacional$factor
defunciones_tasasB[defunciones_tasasB$ambito=="nacional",]$defunciones_esperadas_q01_c<-defunciones_tasasB[defunciones_tasasB$ambito=="nacional",]$defunciones_esperadas_q01*correccion_nacional$factor
defunciones_tasasB[defunciones_tasasB$ambito=="nacional",]$defunciones_esperadas_q99_c<-defunciones_tasasB[defunciones_tasasB$ambito=="nacional",]$defunciones_esperadas_q99*correccion_nacional$factor

#Calculo el exceso
defunciones_tasasB$exceso1<-defunciones_tasasB$defunciones_observadas-defunciones_tasasB$defunciones_esperadas

defunciones_tasasB$exceso1_c<-defunciones_tasasB$defunciones_observadas_c-defunciones_tasasB$defunciones_esperadas_c




#Recodificamos el grupo de edad en la tabla poblacion
poblacion_prov$gredad[poblacion_prov$tramo_edad==100]<-6
poblacion_prov$gredad[poblacion_prov$tramo_edad==95]<-6
poblacion_prov$gredad[poblacion_prov$tramo_edad==90]<-6
poblacion_prov$gredad[poblacion_prov$tramo_edad==85]<-6
poblacion_prov$gredad[poblacion_prov$tramo_edad==80]<-5
poblacion_prov$gredad[poblacion_prov$tramo_edad==75]<-5
poblacion_prov$gredad[poblacion_prov$tramo_edad==70]<-4
poblacion_prov$gredad[poblacion_prov$tramo_edad==65]<-4
poblacion_prov$gredad[poblacion_prov$tramo_edad==60]<-3
poblacion_prov$gredad[poblacion_prov$tramo_edad==55]<-3
poblacion_prov$gredad[poblacion_prov$tramo_edad==50]<-3
poblacion_prov$gredad[poblacion_prov$tramo_edad==45]<-3
poblacion_prov$gredad[poblacion_prov$tramo_edad==40]<-2
poblacion_prov$gredad[poblacion_prov$tramo_edad==35]<-2
poblacion_prov$gredad[poblacion_prov$tramo_edad==30]<-2
poblacion_prov$gredad[poblacion_prov$tramo_edad==25]<-2
poblacion_prov$gredad[poblacion_prov$tramo_edad==20]<-2
poblacion_prov$gredad[poblacion_prov$tramo_edad==15]<-2
poblacion_prov$gredad[poblacion_prov$tramo_edad==10]<-1
poblacion_prov$gredad[poblacion_prov$tramo_edad==5]<-1
poblacion_prov$gredad[poblacion_prov$tramo_edad==0]<-1

poblacion<-poblacion_prov[poblacion_prov$ano==2019,]

poblacion<-aggregate(list(pobl = poblacion$pobl), list(gredad = poblacion$gredad), sum)

poblacion_sexo<-aggregate(list(pobl = poblacion_prov$pobl), list(gredad = poblacion_prov$gredad, sexo_id = poblacion_prov$sexo_id), sum)

poblacion_sexo<- rename(poblacion_sexo, cod_sexo = sexo_id)

poblacion_sexo$cod_sexo<-ifelse(poblacion_sexo$cod_sexo==2,6,poblacion_sexo$cod_sexo)

#Importamos la población estandar
pob_estandar <- read.dta13(file.path("C:/Users/ileon/Documents/MoMo/Modelos/Articulo/DATOS/Datos_articulo_mortalidad_2020/salidas_modelo/pob_estandar.dta"))
pob_estandar$gredadc<-pob_estandar$gredad



pob_estandar$gredad[pob_estandar$gredadc==18]<-6
pob_estandar$gredad[pob_estandar$gredadc==17]<-5
pob_estandar$gredad[pob_estandar$gredadc==16]<-5
pob_estandar$gredad[pob_estandar$gredadc==15]<-4
pob_estandar$gredad[pob_estandar$gredadc==14]<-4
pob_estandar$gredad[pob_estandar$gredadc==13]<-3
pob_estandar$gredad[pob_estandar$gredadc==12]<-3
pob_estandar$gredad[pob_estandar$gredadc==11]<-3
pob_estandar$gredad[pob_estandar$gredadc==10]<-3
pob_estandar$gredad[pob_estandar$gredadc==9]<-2
pob_estandar$gredad[pob_estandar$gredadc==8]<-2
pob_estandar$gredad[pob_estandar$gredadc==7]<-2
pob_estandar$gredad[pob_estandar$gredadc==6]<-2
pob_estandar$gredad[pob_estandar$gredadc==5]<-2
pob_estandar$gredad[pob_estandar$gredadc==4]<-2
pob_estandar$gredad[pob_estandar$gredadc==3]<-1
pob_estandar$gredad[pob_estandar$gredadc==2]<-1
pob_estandar$gredad[pob_estandar$gredadc==1]<-1

#defunciones_tasas$def<-defunciones_tasas$def*defunciones_tasas$factor

pob_estandarC<-pob_estandar %>%
  group_by(gredad)  %>%
  summarize(pob_euro= sum(pob_euro))

#Tasas ajustadas primera ola: 2020-03-01  -   2020-06-21
defunciones_tasasB$cod_provincia<-defunciones_tasasB$cod_ine_ambito

defunciones_tasasB<-defunciones_tasasB[defunciones_tasasB$cod_sexo=="all" & defunciones_tasasB$gredad<=6,]


#Creo un mapa por cada ola
defunciones_tasas_prov1<-defunciones_tasasB[(defunciones_tasasB$fdef>="2020-03-01" & defunciones_tasasB$fdef<="2020-06-21"),] %>%
  group_by(gredad, cod_provincia)  %>%
  summarize(def= sum(exceso1_c))


poblacion_prov<-poblacion_prov[poblacion_prov$ano==2019,]
poblacion_provT<-aggregate(list(pobl = poblacion_prov$pobl), list(cod_provincia=poblacion_prov$prov, gredad = poblacion_prov$gredad), sum)

defunciones_tasas_prov1<-merge(defunciones_tasas_prov1, poblacion_provT, by=c("gredad", "cod_provincia"), all=TRUE)

defunciones_tasas_prov1<-defunciones_tasas_prov1[defunciones_tasas_prov1$gredad<=6,]


defunciones_tasas_prov1<-merge(defunciones_tasas_prov1, pob_estandarC, by=c("gredad"), all=TRUE)



defunciones_tasas_prov1$def<-ifelse(is.na(defunciones_tasas_prov1$def)==TRUE,0,defunciones_tasas_prov1$def)


defunciones_tasas_prov1$tasas<-defunciones_tasas_prov1$def/defunciones_tasas_prov1$pobl
defunciones_tasas_prov1$tasasaj<-(defunciones_tasas_prov1$def/defunciones_tasas_prov1$pobl)*defunciones_tasas_prov1$pob_euro
defunciones_tasasaj_prov11<-aggregate(list(tasasaj = defunciones_tasas_prov1$tasasaj), list(cod_provincia=defunciones_tasas_prov1$cod_provincia), sum)




defunciones_tasasaj_prov11$cod_provincia<-as.character(defunciones_tasasaj_prov11$cod_provincia)




defunciones_tasasaj_prov1<-merge(mapa.P, defunciones_tasasaj_prov11, by.x = "provincias", by.y = "cod_provincia")


Tasa1=defunciones_tasasaj_prov1$tasasaj

require(RColorBrewer)
#display.brewer.pal(9,"RdYlGn")
col.RR=brewer.pal(5,"Greys")[1:6]
#breaks.RR = c(0,100,200,300,400)
breaks.RR = c(0,20,40,60,80)


mapas<-function(RR,main="",main.legend="Rate",filename="mapas.pdf",col.regions=col.RR,breaks=breaks.RR,leyenda=TRUE,Pdf=FALSE){
  B=max(breaks)
  if(B>1) {
    f<-cut(RR,c(breaks,max(RR,B)+0.1),include.lowest=TRUE)
    levels(f)[nlevels(f)]<-paste(">",B,sep="");levels(f)[1]<-paste(breaks[2],"<",sep="")
  } else f<-cut(RR,breaks,include.lowest=TRUE)
  tt=sub(",","-",levels(f));levels(f)=gsub("\\(?\\]?\\[?","",tt)#para Bea
  mapa.P$temp=f
  
  par(mar=c(0.5,0.1,1.5,0.5))
  plot(mapa.P,col=col.regions[mapa.P$temp],border="grey60") #más rápido
  #plot(Canarias.move,col=col.regions[Canarias$temp],border="grey60",add=TRUE)
  # PSeparador para la zona de Canarias
  segments(x0=-460390.3,y0=4080000,x1=112243.2,y1=4080000,col="grey48")
  segments(x0=112243.2,y0=4080000,x1=212105.9,y1=3900000,col="grey48")
  legends=paste(levels(f),paste("(",table(f),")",sep=""),sep="  ")
  legend("bottomright", title=main.legend,,legend=legends,
         fill=col.regions, cex=2, bty="o",plot=leyenda)
  invisible(title(main=main,cex.main=1.5))
}


#Segunda ola 2020-06-22  -   2020-12-06
defunciones_tasas_prov2<-defunciones_tasasB[(defunciones_tasasB$fdef>="2020-06-22" & defunciones_tasasB$fdef<="2020-12-06"),] %>%
  group_by(gredad, cod_provincia)  %>%
  summarize(def= sum(exceso1_c))





poblacion_prov<-poblacion_prov[poblacion_prov$ano==2019,]
poblacion_provT<-aggregate(list(pobl = poblacion_prov$pobl), list(cod_provincia=poblacion_prov$prov, gredad = poblacion_prov$gredad), sum)

defunciones_tasas_prov2<-merge(defunciones_tasas_prov2, poblacion_provT, by=c("gredad", "cod_provincia"), all=TRUE)



defunciones_tasas_prov2<-merge(defunciones_tasas_prov2, pob_estandarC, by=c("gredad"), all=TRUE)

defunciones_tasas_prov2$def<-ifelse(is.na(defunciones_tasas_prov2$def)==TRUE,0,defunciones_tasas_prov2$def)



defunciones_tasas_prov2$tasas<-defunciones_tasas_prov2$def/defunciones_tasas_prov2$pobl
defunciones_tasas_prov2$tasasaj<-(defunciones_tasas_prov2$def/defunciones_tasas_prov2$pobl)*defunciones_tasas_prov2$pob_euro
defunciones_tasasaj_prov22<-aggregate(list(tasasaj = defunciones_tasas_prov2$tasasaj), list(cod_provincia=defunciones_tasas_prov2$cod_provincia), sum)


defunciones_tasasaj_prov22$cod_provincia<-as.character(defunciones_tasasaj_prov22$cod_provincia)




defunciones_tasasaj_prov2<-merge(mapa.P, defunciones_tasasaj_prov22, by.x = "provincias", by.y = "cod_provincia")


Tasa2=defunciones_tasasaj_prov2$tasasaj

#require(RColorBrewer)
#display.brewer.pal(9,"RdYlGn")
#col.RR=brewer.pal(5,"YlGnBu")[1:6]
#breaks.RR = c(0,0,100,200,300,400)



mapas<-function(RR,main="",main.legend="Rate",filename="mapas.pdf",col.regions=col.RR,breaks=breaks.RR,leyenda=TRUE,Pdf=FALSE){
  B=max(breaks)
  if(B>1) {
    f<-cut(RR,c(breaks,max(RR,B)+0.1),include.lowest=TRUE)
    levels(f)[nlevels(f)]<-paste(">",B,sep="");levels(f)[1]<-paste(breaks[2],"<",sep="")
  } else f<-cut(RR,breaks,include.lowest=TRUE)
  tt=sub(",","-",levels(f));levels(f)=gsub("\\(?\\]?\\[?","",tt)#para Bea
  mapa.P$temp=f
  
  par(mar=c(0.5,0.1,1.5,0.5))
  plot(mapa.P,col=col.regions[mapa.P$temp],border="grey60") #más rápido
  #plot(Canarias.move,col=col.regions[Canarias$temp],border="grey60",add=TRUE)
  # PSeparador para la zona de Canarias
  segments(x0=-460390.3,y0=4080000,x1=112243.2,y1=4080000,col="grey48")
  segments(x0=112243.2,y0=4080000,x1=212105.9,y1=3900000,col="grey48")
  legends=paste(levels(f),paste("(",table(f),")",sep=""),sep="  ")
  legend("bottomright", title=main.legend,,legend=legends,
         fill=col.regions, cex=1, bty="o",plot=leyenda)
  invisible(title(main=main,cex.main=1.5))
}


#Tercera ola 2020-12-07  -   2021-03-14
defunciones_tasas_prov3<-defunciones_tasasB[(defunciones_tasasB$fdef>="2020-12-07" & defunciones_tasasB$fdef<="2021-03-14"),] %>%
  group_by(gredad, cod_provincia)  %>%
  summarize(def= sum(exceso1_c))

poblacion_prov<-poblacion_prov[poblacion_prov$ano==2019,]
poblacion_provT<-aggregate(list(pobl = poblacion_prov$pobl), list(cod_provincia=poblacion_prov$prov, gredad = poblacion_prov$gredad), sum)

defunciones_tasas_prov3<-merge(defunciones_tasas_prov3, poblacion_provT, by=c("gredad", "cod_provincia"), all=TRUE)

defunciones_tasas_prov3<-defunciones_tasas_prov3[defunciones_tasas_prov3$gredad<=6,]

defunciones_tasas_prov3<-merge(defunciones_tasas_prov3, pob_estandarC, by=c("gredad"), all=TRUE)

defunciones_tasas_prov3$def<-ifelse(is.na(defunciones_tasas_prov3$def)==TRUE,0,defunciones_tasas_prov3$def)

defunciones_tasas_prov3$tasas<-defunciones_tasas_prov3$def/defunciones_tasas_prov3$pobl
defunciones_tasas_prov3$tasasaj<-(defunciones_tasas_prov3$def/defunciones_tasas_prov3$pobl)*defunciones_tasas_prov3$pob_euro
defunciones_tasasaj_prov33<-aggregate(list(tasasaj = defunciones_tasas_prov3$tasasaj), list(cod_provincia=defunciones_tasas_prov3$cod_provincia), sum)


defunciones_tasasaj_prov33$cod_provincia<-as.character(defunciones_tasasaj_prov33$cod_provincia)

defunciones_tasasaj_prov33$tasasaj<-ifelse(defunciones_tasasaj_prov33$tasasaj<0,0,defunciones_tasasaj_prov33$tasasaj)


defunciones_tasasaj_prov3<-merge(mapa.P, defunciones_tasasaj_prov33, by.x = "provincias", by.y = "cod_provincia")


Tasa3=defunciones_tasasaj_prov3$tasasaj

#require(RColorBrewer)
#display.brewer.pal(9,"RdYlGn")
#col.RR=brewer.pal(5,"YlGnBu")[1:6]
#breaks.RR = c(0,0,100,200,300,400)



mapas<-function(RR,main="",main.legend="Rate",filename="mapas.pdf",col.regions=col.RR,breaks=breaks.RR,leyenda=TRUE,Pdf=FALSE){
  B=max(breaks)
  if(B>1) {
    f<-cut(RR,c(breaks,max(RR,B)+0.1),include.lowest=TRUE)
    levels(f)[nlevels(f)]<-paste(">",B,sep="");levels(f)[1]<-paste(breaks[2],"<",sep="")
  } else f<-cut(RR,breaks,include.lowest=TRUE)
  tt=sub(",","-",levels(f));levels(f)=gsub("\\(?\\]?\\[?","",tt)#para Bea
  mapa.P$temp=f
  
  par(mar=c(0.5,0.1,1.5,0.5))
  plot(mapa.P,col=col.regions[mapa.P$temp],border="grey60") #más rápido
  #plot(Canarias.move,col=col.regions[Canarias$temp],border="grey60",add=TRUE)
  # PSeparador para la zona de Canarias
  segments(x0=-460390.3,y0=4080000,x1=112243.2,y1=4080000,col="grey48")
  segments(x0=112243.2,y0=4080000,x1=212105.9,y1=3900000,col="grey48")
  legends=paste(levels(f),paste("(",table(f),")",sep=""),sep="  ")
  legend("bottomright", title=main.legend,,legend=legends,
         fill=col.regions, cex=1, bty="o",plot=leyenda)
  invisible(title(main=main,cex.main=1.5))
}




######## MAPA provinciales de España de defunciones covid

covid$edad<-as.numeric(covid$edad)

covid$edad<-as.numeric(covid$edad)
covid$gredad <- 99
covid$gredad[covid$edad >= 85] <- 18
covid$gredad[covid$edad < 85] <- 17
covid$gredad[covid$edad < 80] <- 16
covid$gredad[covid$edad < 75] <- 15
covid$gredad[covid$edad < 70] <- 14
covid$gredad[covid$edad < 65] <- 13
covid$gredad[covid$edad < 60] <- 12
covid$gredad[covid$edad < 55] <- 11
covid$gredad[covid$edad < 50] <- 10
covid$gredad[covid$edad < 45] <- 9
covid$gredad[covid$edad < 40] <- 8
covid$gredad[covid$edad < 35] <- 7
covid$gredad[covid$edad < 30] <- 6
covid$gredad[covid$edad < 25] <- 5
covid$gredad[covid$edad < 20] <- 4
covid$gredad[covid$edad < 15] <- 3
covid$gredad[covid$edad < 10] <- 2
covid$gredad[covid$edad < 5] <- 1
covid$def<-1

#Tasas ajustadas primera ola: 2020-03-01  -   2020-06-21
covid_prov1<-covid[(covid$date>="2020-03-01" & covid$date<="2020-06-21"),] 

covid1<-merge(covid_prov1, poblacion_provT, by.x=c("gredad", "cod_iso_prov"), by.y=c("gredad", "cod_provincia"), all=TRUE)

covid11<-merge(covid1, pob_estandar, by=c("gredad"), all=TRUE)
covid11$def<-ifelse(is.na(covid11$def)==TRUE,0,covid11$def)


covid_tasas_prov1<-covid11 %>%
  group_by(gredad, cod_iso_prov)  %>%
  summarize(def= sum(def), minimo=min(edad), maximo=max(edad), pobl=sum(pobl), pob_euro=sum(pob_euro))



covid_tasas_prov1$tasas<-covid_tasas_prov1$def/covid_tasas_prov1$pobl
covid_tasas_prov1$tasasaj<-(covid_tasas_prov1$def/covid_tasas_prov1$pobl)*covid_tasas_prov1$pob_euro

covid_tasas_prov1<-covid_tasas_prov1[covid_tasas_prov1$cod_iso_prov!=99,]
covid_tasas_prov1<-covid_tasas_prov1[covid_tasas_prov1$gredad!=99,]


covid_tasaj11<-aggregate(list(tasasaj = covid_tasas_prov1$tasasaj), list(cod_provincia=covid_tasas_prov1$cod_iso_prov), sum)


covid_tasaj<-merge(mapa.P, covid_tasaj11, by.x = "provincias", by.y = "cod_provincia", all=TRUE)

breaks.RR = c(0,20,40,60,80)

Tasa1_covid=covid_tasaj$tasasaj

#win.metafile(file="C:/Users/ileon/Documents/MoMo/Modelos/Articulo/DATOS/Datos_articulo_mortalidad_2020/salidas_modelo/mapa1_covid.wmf",13,6)

#layout(matrix(1:2,1,2))
mapas(Tasa1_covid)

#dev.off()






#Segunda ola 2020-06-22  -   2020-12-06

covid_prov2<-covid[(covid$date>="2020-06-22" & covid$date<="2020-12-06"),] 

covid2<-merge(covid_prov2, poblacion_provT, by.x=c("gredad", "cod_iso_prov"), by.y=c("gredad", "cod_provincia"), all=TRUE)

covid22<-merge(covid2, pob_estandar, by=c("gredad"), all=TRUE)
covid22$def<-ifelse(is.na(covid22$def)==TRUE,0,covid22$def)



covid_tasas_prov2<-covid22 %>%
  group_by(gredad, cod_iso_prov)  %>%
  summarize(def= sum(def), minimo=min(edad), maximo=max(edad), pobl=sum(pobl), pob_euro=sum(pob_euro))


covid_tasas_prov2$tasas<-covid_tasas_prov2$def/covid_tasas_prov2$pobl
covid_tasas_prov2$tasasaj<-(covid_tasas_prov2$def/covid_tasas_prov2$pobl)*covid_tasas_prov2$pob_euro


covid_tasas_prov2<-covid_tasas_prov2[covid_tasas_prov2$cod_iso_prov!=99,]
covid_tasas_prov2<-covid_tasas_prov2[covid_tasas_prov2$gredad!=99,]

covid_tasaj22<-aggregate(list(tasasaj = covid_tasas_prov2$tasasaj), list(cod_provincia=covid_tasas_prov2$cod_iso_prov), sum)


covid_tasaj2<-merge(mapa.P, covid_tasaj22, by.x = "provincias", by.y = "cod_provincia", all=TRUE)


Tasa2_covid=covid_tasaj2$tasasaj



#win.metafile(file="C:/Users/ileon/Documents/MoMo/Modelos/Articulo/DATOS/Datos_articulo_mortalidad_2020/salidas_modelo/mapa2_covid.wmf",13,6)

#layout(matrix(1:2,1,2))
mapas(Tasa2_covid)

#dev.off()




#Tercera ola 22020-12-07  -   2021-03-14
covid_prov3<-covid[(covid$date>="2020-12-07" & covid$date<="2021-03-14"),] 

covid3<-merge(covid_prov3, poblacion_provT, by.x=c("gredad", "cod_iso_prov"), by.y=c("gredad", "cod_provincia"), all=TRUE)

covid33<-merge(covid3, pob_estandar, by=c("gredad"), all=TRUE)
covid33$def<-ifelse(is.na(covid33$def)==TRUE,0,covid33$def)


covid_tasas_prov3<-covid33%>%
  group_by(gredad, cod_iso_prov)  %>%
  summarize(def= sum(def), minimo=min(edad), maximo=max(edad), pobl=sum(pobl), pob_euro=sum(pob_euro))


covid_tasas_prov3$tasas<-covid_tasas_prov3$def/covid_tasas_prov3$pobl
covid_tasas_prov3$tasasaj<-(covid_tasas_prov3$def/covid_tasas_prov3$pobl)*covid_tasas_prov3$pob_euro

covid_tasas_prov3<-covid_tasas_prov3[covid_tasas_prov3$cod_iso_prov!=99,]
covid_tasas_prov3<-covid_tasas_prov3[covid_tasas_prov3$gredad!=99,]
covid_tasaj33<-aggregate(list(tasasaj = covid_tasas_prov3$tasasaj), list(cod_provincia=covid_tasas_prov3$cod_iso_prov), sum)


covid_tasaj3<-merge(mapa.P, covid_tasaj33, by.x = "provincias", by.y = "cod_provincia", all=TRUE)


Tasa3_covid=covid_tasaj3$tasasaj

#win.metafile(file="C:/Users/ileon/Documents/MoMo/Modelos/Articulo/DATOS/Datos_articulo_mortalidad_2020/salidas_modelo/mapa3_covid.wmf",13,6)

#layout(matrix(1:2,1,2))
mapas(Tasa3_covid)

#
dev.off()


mapas<-function(RR,main="",main.legend="Excess deaths/100,000",filename="mapas.pdf",col.regions=col.RR,breaks=breaks.RR,leyenda=TRUE,Pdf=FALSE){
  B=max(breaks)
  if(B>1) {
    f<-cut(RR,c(breaks,max(RR,B)+0.1),include.lowest=TRUE)
    levels(f)[nlevels(f)]<-paste(">",B,sep="");levels(f)[1]<-paste(breaks[2],"<",sep="")
  } else f<-cut(RR,breaks,include.lowest=TRUE)
  tt=sub(",","-",levels(f));levels(f)=gsub("\\(?\\]?\\[?","",tt)#para Bea
  mapa.P$temp=f
  
  par(mar=c(0.5,0.1,1.5,0.5))
  plot(mapa.P,col=col.regions[mapa.P$temp],border="grey60") #más rápido
  #plot(Canarias.move,col=col.regions[Canarias$temp],border="grey60",add=TRUE)
  # PSeparador para la zona de Canarias
  segments(x0=-460390.3,y0=4080000,x1=112243.2,y1=4080000,col="grey48")
  segments(x0=112243.2,y0=4080000,x1=212105.9,y1=3900000,col="grey48")
  legends=paste(levels(f),paste("(",table(f),")",sep=""),sep="  ")
  legend("bottomright", title=main.legend,,legend=legends,
         fill=col.regions, cex=1.5, bty="o",plot=leyenda)
  invisible(title(main=main,cex.main=1.5))
}

mapas1<-function(RR,main="",main.legend="COVID-19 deaths/100,000",filename="mapas.pdf",col.regions=col.RR,breaks=breaks.RR,leyenda=TRUE,Pdf=FALSE){
  B=max(breaks)
  if(B>1) {
    f<-cut(RR,c(breaks,max(RR,B)+0.1),include.lowest=TRUE)
    levels(f)[nlevels(f)]<-paste(">",B,sep="");levels(f)[1]<-paste(breaks[2],"<",sep="")
  } else f<-cut(RR,breaks,include.lowest=TRUE)
  tt=sub(",","-",levels(f));levels(f)=gsub("\\(?\\]?\\[?","",tt)#para Bea
  mapa.P$temp=f
  
  par(mar=c(0.5,0.1,1.5,0.5))
  plot(mapa.P,col=col.regions[mapa.P$temp],border="grey60") #más rápido
  #plot(Canarias.move,col=col.regions[Canarias$temp],border="grey60",add=TRUE)
  # PSeparador para la zona de Canarias
  segments(x0=-460390.3,y0=4080000,x1=112243.2,y1=4080000,col="grey48")
  segments(x0=112243.2,y0=4080000,x1=212105.9,y1=3900000,col="grey48")
  legends=paste(levels(f),paste("(",table(f),")",sep=""),sep="  ")
  legend("bottomright", title=main.legend,,legend=legends,
         fill=col.regions, cex=1.5, bty="o",plot=leyenda)
  invisible(title(main=main,cex.main=1.5))
}
jpeg("Y:/COVID-19/Artículo2_MoMo_Covid19 deaths/Manuscrito/Figuras_tablas/Figure4.jpeg", units="in", width=15, height=10, res=300)

par(mfrow=c(3,2))
#win.metafile(file="C:/Users/ileon/Documents/MoMo/Modelos/Articulo/DATOS/Datos_articulo_mortalidad_2020/salidas_modelo/mapa1.wmf")
#layout(matrix(1:2,1,2))
col.RR=brewer.pal(5,"YlGnBu")[1:6]
#breaks.RR = c(0,100,200,300,400)
breaks.RR = c(0,20,40,60,80)
mapas(Tasa1)

#title(main="A) Cumulative excess all-causes mortality rates MoMo", cex.main=2.5)
title("First wave", adj=0, line=-4, cex.main=2)

breaks.RR = c(0,20,40,60,80)
mapas1(Tasa1_covid)

#title("B) Cumulative COVID-19 mortality rates", cex.main=2.5)

#breaks.RR = c(0,100,200,300,400)
breaks.RR = c(0,20,40,60,80)
mapas(Tasa2)
title("Second wave", adj=-0, line=-4, cex.main=2)

breaks.RR = c(0,20,40,60,80)
mapas1(Tasa2_covid)

#breaks.RR = c(0,100,200,300,400)
breaks.RR = c(0,20,40,60,80)
mapas(Tasa3)
title( "Third wave", adj=-0, line=-4, cex.main=2)

breaks.RR = c(0,20,40,60,80)
mapas1(Tasa3_covid)
dev.off()





mapas<-function(RR,main="",main.legend="Excess deaths/100,000",filename="mapas.pdf",col.regions=col.RR,breaks=breaks.RR,leyenda=TRUE,Pdf=FALSE){
  B=max(breaks)
  if(B>1) {
    f<-cut(RR,c(breaks,max(RR,B)+0.1),include.lowest=TRUE)
    levels(f)[nlevels(f)]<-paste(">",B,sep="");levels(f)[1]<-paste(breaks[2],"<",sep="")
  } else f<-cut(RR,breaks,include.lowest=TRUE)
  tt=sub(",","-",levels(f));levels(f)=gsub("\\(?\\]?\\[?","",tt)#para Bea
  mapa.P$temp=f
  
  par(mar=c(0.5,0.1,1.5,0.5))
  plot(mapa.P,col=col.regions[mapa.P$temp],border="white") #más rápido
  #plot(Canarias.move,col=col.regions[Canarias$temp],border="grey60",add=TRUE)
  # PSeparador para la zona de Canarias
  segments(x0=-460390.3,y0=4080000,x1=112243.2,y1=4080000,col="white")
  segments(x0=112243.2,y0=4080000,x1=212105.9,y1=3900000,col="white")
  legends=paste(levels(f),paste("(",table(f),")",sep=""),sep="  ")
  legend("bottomright", title=main.legend,,legend=legends,
         fill=col.regions, cex=1.5, bty="o",plot=leyenda)
  invisible(title(main=main,cex.main=1.5))
}


mapas1<-function(RR,main="",main.legend="COVID-19 deaths/100,000",filename="mapas.pdf",col.regions=col.RR,breaks=breaks.RR,leyenda=TRUE,Pdf=FALSE){
  B=max(breaks)
  if(B>1) {
    f<-cut(RR,c(breaks,max(RR,B)+0.1),include.lowest=TRUE)
    levels(f)[nlevels(f)]<-paste(">",B,sep="");levels(f)[1]<-paste(breaks[2],"<",sep="")
  } else f<-cut(RR,breaks,include.lowest=TRUE)
  tt=sub(",","-",levels(f));levels(f)=gsub("\\(?\\]?\\[?","",tt)#para Bea
  mapa.P$temp=f
  
  par(mar=c(0.5,0.1,1.5,0.5))
  plot(mapa.P,col=col.regions[mapa.P$temp],border="white") #más rápido
  #plot(Canarias.move,col=col.regions[Canarias$temp],border="grey60",add=TRUE)
  # PSeparador para la zona de Canarias
  segments(x0=-460390.3,y0=4080000,x1=112243.2,y1=4080000,col="white")
  segments(x0=112243.2,y0=4080000,x1=212105.9,y1=3900000,col="white")
  legends=paste(levels(f),paste("(",table(f),")",sep=""),sep="  ")
  legend("bottomright", title=main.legend,,legend=legends,
         fill=col.regions, cex=1.5, bty="o",plot=leyenda)
  invisible(title(main=main,cex.main=1.5))
}
jpeg("Y:/COVID-19/Artículo2_MoMo_Covid19 deaths/Manuscrito/Figuras_tablas/Figure4_BN.jpeg", units="in", width=15, height=10, res=300)

par(mfrow=c(3,2))
#win.metafile(file="C:/Users/ileon/Documents/MoMo/Modelos/Articulo/DATOS/Datos_articulo_mortalidad_2020/salidas_modelo/mapa1.wmf")
#layout(matrix(1:2,1,2))
col.RR=brewer.pal(9,"Greys")[4:8]
#breaks.RR = c(0,100,200,300,400)
breaks.RR = c(0,20,40,60,80)
mapas(Tasa1)

#title(main="A) Cumulative excess all-causes mortality rates MoMo", cex.main=2.5)
title("First wave", adj=0, line=-4, cex.main=2)

breaks.RR = c(0,20,40,60,80)
mapas1(Tasa1_covid)

#title("B) Cumulative COVID-19 mortality rates", cex.main=2.5)

#breaks.RR = c(0,100,200,300,400)
breaks.RR = c(0,20,40,60,80)
mapas(Tasa2)
title("Second wave", adj=-0, line=-4, cex.main=2)

breaks.RR = c(0,20,40,60,80)
mapas1(Tasa2_covid)

#breaks.RR = c(0,100,200,300,400)
breaks.RR = c(0,20,40,60,80)
mapas(Tasa3)
title( "Third wave", adj=-0, line=-4, cex.main=2)

breaks.RR = c(0,20,40,60,80)
mapas1(Tasa3_covid)
dev.off()





